==> igniteui-react-18.2.2-beta.0.tgz: package/esm2015/lib/LinearProgress.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ProgressBase } from "./ProgressBase";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { LinearProgressLabelAlign_$type } from "./LinearProgressLabelAlign";
/**
 * @hidden
 */
export let LinearProgress = /*@__PURE__*/ (() => {
    class LinearProgress extends ProgressBase {
        get o() {
            let ret_ = this.c.m("striped");
            return ret_;
        }
        set o(a) {
            let value_ = a;
            this.c.u("striped", value_);
        }
        get n() {
            let ret_ = this.c.m("labelAlign");
            ret_ = enumGetBox(LinearProgressLabelAlign_$type, EnumUtil.getEnumValue(LinearProgressLabelAlign_$type, this.c.f(LinearProgressLabelAlign_$type, ret_)));
            return EnumUtil.getEnumValue(LinearProgressLabelAlign_$type, ret_);
        }
        set n(a) {
            let value_ = enumGetBox(LinearProgressLabelAlign_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.c.u("labelAlign", value_);
        }
    }
    LinearProgress.$t = /*@__PURE__*/ markType(LinearProgress, 'LinearProgress', ProgressBase.$);
    return LinearProgress;
})();

==> igniteui-react-18.3.0-beta.0.tgz: package/esm2015/lib/LinearProgress.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ProgressBase } from "./ProgressBase";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { LinearProgressLabelAlign_$type } from "./LinearProgressLabelAlign";
/**
 * @hidden
 */
export let LinearProgress = /*@__PURE__*/ (() => {
    class LinearProgress extends ProgressBase {
        get o() {
            let ret_ = this.c.n("striped");
            return ret_;
        }
        set o(a) {
            let value_ = a;
            this.c.v("striped", value_);
        }
        get n() {
            let ret_ = this.c.n("labelAlign");
            ret_ = enumGetBox(LinearProgressLabelAlign_$type, EnumUtil.getEnumValue(LinearProgressLabelAlign_$type, this.c.f(LinearProgressLabelAlign_$type, ret_)));
            return EnumUtil.getEnumValue(LinearProgressLabelAlign_$type, ret_);
        }
        set n(a) {
            let value_ = enumGetBox(LinearProgressLabelAlign_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.c.v("labelAlign", value_);
        }
    }
    LinearProgress.$t = /*@__PURE__*/ markType(LinearProgress, 'LinearProgress', ProgressBase.$);
    return LinearProgress;
})();
